==> haskell-unixutils-1.54.3-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Unixutils
version:              1.54.3
visibility:           public
id:                   Unixutils-1.54.3-2I74MuWckYL69hWR29YrAz
key:                  Unixutils-1.54.3-2I74MuWckYL69hWR29YrAz
license:              BSD-3-Clause
maintainer:           David Fox <ddssff@gmail.com>
author:               Jeremy Shaw, David Fox
homepage:             https://github.com/seereason/haskell-unixutils.git
synopsis:
    A crude interface between Haskell and Unix-like operating systems

description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.

category:             System
abi:                  f3f02eea0527ffdbb3870fcbefd85fad
exposed:              True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice

import-dirs:          /usr/lib/ghc-9.4.8/site-local/Unixutils-1.54.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Unixutils-1.54.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Unixutils-1.54.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unixutils
hs-libraries:         HSUnixutils-1.54.3-2I74MuWckYL69hWR29YrAz
extra-libraries:      crypt
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2 mtl-2.2.2 process-1.6.18.0
    process-extras-0.7.4-3D8s4SWgT3G4YJfytFErKP
    pureMD5-2.1.4-6BAlx1YcRzfGjM1aVlHnl3
    regex-tdfa-1.3.2.4-DyGMbh1NpFc9rSkmhAEdJe unix-2.7.3
    zlib-0.6.3.0-LpsU7RxXEmX5AsdSWV7cLM

haddock-interfaces:   /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html:         /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unixutils-1.54.3-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Unixutils
version:              1.54.3
visibility:           public
id:                   Unixutils-1.54.3-IcJC81glsjFL6AlP6w79BV
key:                  Unixutils-1.54.3-IcJC81glsjFL6AlP6w79BV
license:              BSD-3-Clause
maintainer:           David Fox <ddssff@gmail.com>
author:               Jeremy Shaw, David Fox
homepage:             https://github.com/seereason/haskell-unixutils.git
synopsis:
    A crude interface between Haskell and Unix-like operating systems

description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.

category:             System
abi:                  a2dfa6ff94cc51b4149576243366a6af
exposed:              True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice

import-dirs:          /usr/lib/ghc-9.4.8/site-local/Unixutils-1.54.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Unixutils-1.54.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Unixutils-1.54.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unixutils
hs-libraries:         HSUnixutils-1.54.3-IcJC81glsjFL6AlP6w79BV
extra-libraries:      crypt
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2 mtl-2.2.2 process-1.6.18.0
    process-extras-0.7.4-GAwGMRjoweEF4pvKbU0qZ6
    pureMD5-2.1.4-6BAlx1YcRzfGjM1aVlHnl3
    regex-tdfa-1.3.2.4-AAuM6ZM4tbzHRXDs6OdINo unix-2.7.3
    zlib-0.6.3.0-DQJ3sjglCnhJjpkMXQsJJY

haddock-interfaces:   /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html:         /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
